@@ -4,12 +4,12 @@ from os.path import normpath
 from pprint import pformat, saferepr
 
 from django import http
-from django.conf.urls import url
 from django.core import signing
 from django.db.models.query import QuerySet, RawQuerySet
 from django.template import RequestContext, Template
 from django.test.signals import template_rendered
 from django.test.utils import instrumented_test_render
+from django.urls import path
 from django.utils.translation import gettext_lazy as _
 
 from debug_toolbar.panels import Panel
@@ -67,15 +67,8 @@ class TemplatesPanel(Panel):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.templates = []
-        # Refs GitHub issue #910
-        # Hold a series of seen dictionaries within Contexts. A dictionary is
-        # considered seen if it is `in` this list, requiring that the __eq__
-        # for the dictionary matches. If *anything* in the dictionary is
-        # different it is counted as a new layer.
-        self.seen_layers = []
-        # Holds all dictionaries which have been prettified for output.
-        # This should align with the seen_layers such that an index here is
-        # the same as the index there.
+        # An associated list of dictionaries and their prettified
+        # representation.
         self.pformat_layers = []
 
     def _store_template_info(self, sender, **kwargs):
@@ -94,19 +87,18 @@ class TemplatesPanel(Panel):
         context_list = []
         for context_layer in context.dicts:
             if hasattr(context_layer, "items") and context_layer:
-                # Refs GitHub issue #910
-                # If we can find this layer in our pseudo-cache then find the
-                # matching prettified version in the associated list.
-                key_values = sorted(context_layer.items())
-                if key_values in self.seen_layers:
-                    index = self.seen_layers.index(key_values)
-                    pformatted = self.pformat_layers[index]
-                    context_list.append(pformatted)
-                else:
+                # Check if the layer is in the cache.
+                pformatted = None
+                for key_values, _pformatted in self.pformat_layers:
+                    if key_values == context_layer:
+                        pformatted = _pformatted
+                        break
+
+                if pformatted is None:
                     temp_layer = {}
                     for key, value in context_layer.items():
                         # Replace any request elements - they have a large
-                        # unicode representation and the request data is
+                        # Unicode representation and the request data is
                         # already made available from the Request panel.
                         if isinstance(value, http.HttpRequest):
                             temp_layer[key] = "<<request>>"
@@ -121,39 +113,27 @@ class TemplatesPanel(Panel):
                         # QuerySet would trigger the database: user can run the
                         # query from SQL Panel
                         elif isinstance(value, (QuerySet, RawQuerySet)):
-                            model_name = "{}.{}".format(
-                                value.model._meta.app_label, value.model.__name__
-                            )
                             temp_layer[key] = "<<{} of {}>>".format(
-                                value.__class__.__name__.lower(), model_name
+                                value.__class__.__name__.lower(),
+                                value.model._meta.label,
                             )
                         else:
+                            recording(False)
                             try:
-                                recording(False)
                                 saferepr(value)  # this MAY trigger a db query
                             except SQLQueryTriggered:
                                 temp_layer[key] = "<<triggers database query>>"
                             except UnicodeEncodeError:
-                                temp_layer[key] = "<<unicode encode error>>"
+                                temp_layer[key] = "<<Unicode encode error>>"
                             except Exception:
                                 temp_layer[key] = "<<unhandled exception>>"
                             else:
                                 temp_layer[key] = value
                             finally:
                                 recording(True)
-                    # Execute pformat first - if for some reason pformat/repr
-                    # causes more templates to be rendered, seen/pformat layers
-                    # will still be consistent
                     pformatted = pformat(temp_layer)
-                    # Refs GitHub issue #910
-                    # If we've not seen the layer before then we will add it
-                    # so that if we see it again we can skip formatting it.
-                    self.seen_layers.append(key_values)
-                    # Note: this *ought* to be len(...) - 1 but let's be safe.
-                    index = self.seen_layers.index(key_values)
-                    # Note: this *ought* to be len(...) - 1 but let's be safe.
-                    self.pformat_layers.insert(index, pformatted)
-                    context_list.append(pformatted)
+                    self.pformat_layers.append((context_layer, pformatted))
+                context_list.append(pformatted)
 
         kwargs["context"] = context_list
         kwargs["context_processors"] = getattr(context, "context_processors", None)
@@ -180,9 +160,7 @@ class TemplatesPanel(Panel):
 
     @classmethod
     def get_urls(cls):
-        return [
-            url(r"^template_source/$", views.template_source, name="template_source")
-        ]
+        return [path("template_source/", views.template_source, name="template_source")]
 
     def enable_instrumentation(self):
         template_rendered.connect(self._store_template_info)
@@ -195,7 +173,7 @@ class TemplatesPanel(Panel):
         for template_data in self.templates:
             info = {}
             # Clean up some info about templates
-            template = template_data.get("template", None)
+            template = template_data["template"]
             if hasattr(template, "origin") and template.origin and template.origin.name:
                 template.origin_name = template.origin.name
                 template.origin_hash = signing.dumps(template.origin.name)
