@@ -1,8 +1,8 @@
 from django.core import signing
-from django.http import HttpResponseBadRequest
+from django.http import HttpResponseBadRequest, JsonResponse
 from django.template import Origin, TemplateDoesNotExist
 from django.template.engine import Engine
-from django.template.response import SimpleTemplateResponse
+from django.template.loader import render_to_string
 from django.utils.safestring import mark_safe
 
 from debug_toolbar.decorators import require_show_toolbar
@@ -14,7 +14,7 @@ def template_source(request):
     Return the source of a template, syntax-highlighted by Pygments if
     it's available.
     """
-    template_origin_name = request.GET.get("template_origin", None)
+    template_origin_name = request.GET.get("template_origin")
     if template_origin_name is None:
         return HttpResponseBadRequest('"template_origin" key is required')
     try:
@@ -48,8 +48,8 @@ def template_source(request):
 
     try:
         from pygments import highlight
-        from pygments.lexers import HtmlDjangoLexer
         from pygments.formatters import HtmlFormatter
+        from pygments.lexers import HtmlDjangoLexer
 
         source = highlight(source, HtmlDjangoLexer(), HtmlFormatter())
         source = mark_safe(source)
@@ -57,8 +57,8 @@ def template_source(request):
     except ImportError:
         pass
 
-    # Using SimpleTemplateResponse avoids running global context processors.
-    return SimpleTemplateResponse(
+    content = render_to_string(
         "debug_toolbar/panels/template_source.html",
         {"source": source, "template_name": template_name},
     )
+    return JsonResponse({"content": content})
