@@ -79,6 +79,10 @@ class DebugToolbar:
                 raise
 
     def should_render_panels(self):
+        """Determine whether the panels should be rendered during the request
+
+        If False, the panels will be loaded via Ajax.
+        """
         render_panels = self.config["RENDER_PANELS"]
         if render_panels is None:
             render_panels = self.request.META["wsgi.multiprocess"]
@@ -142,7 +146,9 @@ class DebugToolbar:
         # The primary caller of this function is in the middleware which may
         # not have resolver_match set.
         try:
-            resolver_match = request.resolver_match or resolve(request.path)
+            resolver_match = request.resolver_match or resolve(
+                request.path, getattr(request, "urlconf", None)
+            )
         except Resolver404:
             return False
         return resolver_match.namespaces and resolver_match.namespaces[-1] == app_name
