@@ -1,8 +1,8 @@
 from django.contrib.auth.models import User
 from django.template import Context, RequestContext, Template
-from django.test import TestCase, override_settings
+from django.test import override_settings
 
-from ..base import BaseTestCase
+from ..base import BaseTestCase, IntegrationTestCase
 from ..forms import TemplateReprForm
 from ..models import NonAsciiRepr
 
@@ -32,9 +32,14 @@ class TemplatesPanelTestCase(BaseTestCase):
         # ensure the query was NOT logged
         self.assertEqual(len(self.sql_panel._queries), 0)
 
-        ctx = self.panel.templates[0]["context"][1]
-        self.assertIn("<<queryset of auth.User>>", ctx)
-        self.assertIn("<<triggers database query>>", ctx)
+        self.assertEqual(
+            self.panel.templates[0]["context"],
+            [
+                "{'False': False, 'None': None, 'True': True}",
+                "{'deep_queryset': '<<triggers database query>>',\n"
+                " 'queryset': '<<queryset of auth.User>>'}",
+            ],
+        )
 
     def test_template_repr(self):
         # Force widget templates to be included
@@ -69,8 +74,9 @@ class TemplatesPanelTestCase(BaseTestCase):
         self.assertNotIn("nôt åscíì", self.panel.content)
         self.panel.generate_stats(self.request, response)
         # ensure the panel renders correctly.
-        self.assertIn("nôt åscíì", self.panel.content)
-        self.assertValidHTML(self.panel.content)
+        content = self.panel.content
+        self.assertIn("nôt åscíì", content)
+        self.assertValidHTML(content)
 
     def test_custom_context_processor(self):
         response = self.panel.process_request(self.request)
@@ -88,11 +94,22 @@ class TemplatesPanelTestCase(BaseTestCase):
         with self.settings(DEBUG_TOOLBAR_CONFIG=config):
             self.assertFalse(self.panel.enabled)
 
+    def test_empty_context(self):
+        t = Template("")
+        c = Context({})
+        t.render(c)
+
+        # Includes the builtin context but not the empty one.
+        self.assertEqual(
+            self.panel.templates[0]["context"],
+            ["{'False': False, 'None': None, 'True': True}"],
+        )
+
 
 @override_settings(
     DEBUG=True, DEBUG_TOOLBAR_PANELS=["debug_toolbar.panels.templates.TemplatesPanel"]
 )
-class JinjaTemplateTestCase(TestCase):
+class JinjaTemplateTestCase(IntegrationTestCase):
     def test_django_jinja2(self):
         r = self.client.get("/regular_jinja/foobar/")
         self.assertContains(r, "Test for foobar (Jinja)")
