@@ -1,5 +1,5 @@
 from django.contrib.auth.models import User
-from django.http import HttpResponse, HttpResponseRedirect
+from django.http import HttpResponseRedirect, JsonResponse
 from django.shortcuts import render
 from django.template.response import TemplateResponse
 from django.views.decorators.cache import cache_page
@@ -7,7 +7,7 @@ from django.views.decorators.cache import cache_page
 
 def execute_sql(request):
     list(User.objects.all())
-    return HttpResponse()
+    return render(request, "base.html")
 
 
 def regular_view(request, title):
@@ -25,12 +25,16 @@ def new_user(request, username="joe"):
 
 def resolving_view(request, arg1, arg2):
     # see test_url_resolving in tests.py
-    return HttpResponse()
+    return render(request, "base.html")
 
 
 @cache_page(60)
 def cached_view(request):
-    return HttpResponse()
+    return render(request, "base.html")
+
+
+def json_view(request):
+    return JsonResponse({"foo": "bar"})
 
 
 def regular_jinjia_view(request, title):
